@@ -46,7 +46,7 @@ def krig_phenotype(mod, window_width=8, rel_bandwidth=0.5, max_n_pts=10000):
         inds = np.array([*mod.comm[0].keys()])
     xs = mod.comm[0]._get_x(inds)
     ys = mod.comm[0]._get_y(inds)
-    zs = mod.comm[0]._get_z(inds)[:,0]
+    zs = mod.comm[0]._get_z(individs=inds)[:,0]
     OK = OrdinaryKriging(xs, ys, zs, variogram_model='spherical')
     gridx = np.arange(0.5, mod.land.dim[0] + 0.5, 1)
     gridy = np.arange(0.5, mod.land.dim[1] + 0.5, 1)
@@ -485,7 +485,7 @@ def _make_params():
 
                     'init': {
                         #starting number of individs
-                        'N':                5000,
+                        'N':                50000,
                         #carrying-capacity Layer name
                         'K_layer':          'hab',
                         #multiplicative factor for carrying-capacity layer
@@ -501,8 +501,7 @@ def _make_params():
                         # exposed habitat, then that suggests we should
                         # use a K_factor of 67.8 * 208 * 0.1 = 1111.344
                         # NOTE: dividing by 10 for tractability
-                        #'K_factor':         1111.344 / 10,
-                        'K_factor':         5,
+                        'K_factor':         1111.344 / 10,
                         }, # <END> 'init'
 
                 #######################################
@@ -522,8 +521,6 @@ def _make_params():
                         # (e.g. Tinkle et al. 1993), so just leaving sex_ratio at 1
                         #ratio of males to females
                         'sex_ratio':                1/1,
-                        #whether P(birth) should be weighted by parental dist
-                        'dist_weighted_birth':      False,
                         # NOTE: found no information about this, but 0.5 seems
                         # a reasonable default value
                         #intrinsic growth rate
@@ -544,7 +541,9 @@ def _make_params():
                         #radius of mate-search area
                         #NOTE: just have individuals mate close by (i.e. within
                         #12.457m, the average interannual movement distance
-                        'mating_radius':            0.1
+                        'mating_radius':            0.5,
+                        'choose_nearest_mate':      False,
+                        'inverse_dist_mating':      False,
                         }, # <END> 'mating'
 
                 ##########################################
@@ -591,15 +590,15 @@ def _make_params():
                         #concentration of distr of movement direction
                         'direction_distr_kappa':    0,
                         #mean of distr of movement distance
-                        'movement_distance_distr_param1':        0.01704,
+                        'movement_distance_distr_param1':        7e-5,
                         #variance of distr of movement distance
-                        'movement_distance_distr_param2':     2.5e-7,
+                        'movement_distance_distr_param2':     0.3,
                         #mean of distr of dispersal distance
-                        'movement_distance_distr':      'levy',
-                        'dispersal_distance_distr_param1':       0,
+                        'movement_distance_distr':      'lognormal',
+                        'dispersal_distance_distr_param1':       7.5e-4,
                         #variance of distr of dispersal distance
-                        'dispersal_distance_distr_param2':    2.5e-10,
-                        'dispersal_distance_distr':         'levy',
+                        'dispersal_distance_distr_param2':    1,
+                        'dispersal_distance_distr':         'lognormal',
                         'move_surf'     : {
                             #move-surf Layer name
                             'layer':                'hab',
@@ -622,7 +621,7 @@ def _make_params():
                         #file defining custom genomic arch
                         'gen_arch_file':            None,
                         #num of loci
-                        'L':                        100,
+                        'L':                        1000,
                         #starting allele freq (None to draw freqs randomly)
                         #at 0.5
                         'start_p_fixed':            0.5,
@@ -665,9 +664,9 @@ def _make_params():
                                 #trait-selection Layer name
                                 'layer':                'tmp',
                                 #polygenic selection coefficient
-                                'phi':                  0.1,
+                                'phi':                  0.5,
                                 #number of loci underlying trait
-                                'n_loci':               10,
+                                'n_loci':               100,
                                 #mutation rate at loci underlying trait
                                 'mu':                   0,
                                 #mean of distr of effect sizes
