@@ -22,7 +22,7 @@ There are two levels of documentation available:
   which are returned when requesting Python's help on a class or function.
 
 - Detailed documentation is available at the
-  `Geonomics homepage<https://FIX_ME>`_.
+`Geonomics homepage<https://geonomics.readthedocs.io/en/latest/>`_.
 
 All documentation examples assume that `geonomics` has been imported as `gnx`::
 
@@ -379,9 +379,9 @@ def read_parameters_file(filepath):
     with open(filepath, 'r') as f:
         txt = f.read()
     #find all the layer names and spp names
-    lyr_names = re.findall('\S+(?=: \{\n\n\s+#*\n\s+#### layer num\.)', txt)
+    lyr_names = re.findall('\S+(?=: \{\n\n\s+#-*#\n\s+#--- layer num\.)', txt)
     lyr_names = [re.sub("'", '"', n) for n in lyr_names]
-    spp_names = re.findall('\S+(?=: \{\n\n\s+#*\n\s+#### spp num\.)', txt)
+    spp_names = re.findall('\S+(?=: \{\n\n\s+#-*#\n\s+#--- spp num\.)', txt)
     spp_names = [re.sub("'", '"', n) for n in spp_names]
     #get Counter objects of each
     lyr_name_cts = C(lyr_names)
@@ -408,7 +408,7 @@ def read_parameters_file(filepath):
             trt_names = [re.sub("'", '"', n) for n in trt_names]
             trt_name_cts = C(trt_names)
             sect_spp_name = re.findall(
-                        '\S+(?=: \{\n\n\s+#*\n\s+#### spp num\.)', txt)[0]
+                        '\S+(?=: \{\n\n\s+#-*#\n\s+#--- spp num\.)', txt)[0]
             assert set([*trt_name_cts.values()]) == {1}, ("At least one of the"
                 " Trait names provided in the parameters for Species "
                 "%s appears to be used more than once. "
@@ -682,7 +682,7 @@ def run_demo(name, save_figs=False, time_it=False, **kwargs):
             - *'simult select'*: Runs the simultaneous selection demo (example
               2 from the methods paper).
 
-            - *'yosemite'*: Runs the Yosemite demo (example 3 from the methods
+            - *'Yosemite'*: Runs the Yosemite demo (example 3 from the methods
               paper).
 
     save_figs : bool, optional, default: False
@@ -710,17 +710,17 @@ def run_demo(name, save_figs=False, time_it=False, **kwargs):
         visualization methods, or to introspect its structure.)
     """
 
-    if name == 'IBD IBE':
+    if name.lower() == 'ibd ibe':
         params = demos._IBD_IBE._make_params()
         params = make_params_dict(params)
         mod = demos._IBD_IBE._run(params, save_figs, time_it, **kwargs)
 
-    elif name == 'simult select':
+    elif name.lower() == 'simult select':
         params = demos._simult_select._make_params()
         params = make_params_dict(params)
         mod = demos._simult_select._run(params, save_figs, time_it, **kwargs)
 
-    elif name == 'yosemite':
+    elif name.lower() == 'yosemite':
         params = demos._yosemite._make_params()
         params = make_params_dict(params)
         mod = demos._yosemite._run(params, save_figs, time_it, **kwargs)
