@@ -230,6 +230,9 @@ class Species(OD):
         #for use in getting all individs' coordinates
         self._coord_attrgetter = attrgetter('x', 'y')
 
+        # create the burn-in spatial counter
+        self._burnin_spat_tester = burnin.SpatialTester(self)
+
 
     #override the __deepcopy__ method, so that the species can
     #be copy.deepcopy'd (because otherwise this doesn't work for
@@ -329,6 +332,15 @@ class Species(OD):
         # increment age of all individuals
         [ind._set_age_stage() for ind in self.values()];
 
+    # method for running the spatial burn-in test
+    def _do_spatial_burnin_test(self, num_timesteps_back):
+        # first update the counts and diffs arrays
+        # (which count the number of individuals within each landscape cell,
+        # and the diff in that number between last check and this one)
+        self._burnin_spat_tester.update(self)
+        result = self._burnin_spat_tester.run_test(num_timesteps_back)
+        return result
+
     #method to move all individuals simultaneously, and sample
     #their new locations' environment
     def _do_movement(self, land):
@@ -339,7 +351,8 @@ class Species(OD):
     #function for finding all the mating pairs in a species
     def _find_mating_pairs(self):
         mating_pairs = _find_mates(self, sex=self.sex,
-                                   dist_weighted_birth=self.dist_weighted_birth)
+                                   choose_nearest=self.choose_nearest_mate,
+                                   inverse_dist_mating=self.inverse_dist_mating)
         return mating_pairs
 
     #function for executing mating for a species
@@ -883,6 +896,7 @@ class Species(OD):
     # key and its birth-time and birth-location as a length-2 list of values
     def _get_lineage_dicts(self, loci, nodes=None, drop_before_sim=True,
                            time_before_present=True,
+                           use_individs_curr_pos=True,
                            max_time_ago=None,
                            min_time_ago=None):
         if nodes is None:
@@ -895,6 +909,25 @@ class Species(OD):
                                        time_before_present=time_before_present,
                                        max_time_ago=max_time_ago,
                                        min_time_ago=min_time_ago)
+        # if requested, put the current individuals' current 
+        # positions in the lineage dicts, rather than using the birth
+        # positions (which are in there by default because those
+        # are the positions that are stored within the tskit tables)
+        if use_individs_curr_pos:
+            for locus in lin_dicts.keys():
+                for curr_node_id in lin_dicts[locus].keys():
+                    if len(lin_dicts[locus][curr_node_id]) > 0:
+                        tc_individs_id = self._tc.nodes[curr_node_id].individual
+                        individ = [ind for ind in self.values() if
+                                   ind._individuals_tab_id == tc_individs_id]
+                        assert len(individ) == 1, ("Found multiple individuals "
+                                                   "with the same individuals id "
+                                                   "in the tskit tables.")
+                        individ = individ[0]
+                        curr_pos = np.array([individ.x, individ.y])
+                        birth_t = lin_dicts[locus][curr_node_id][curr_node_id][0]
+                        lin_dicts[locus][curr_node_id][curr_node_id] = (birth_t,
+                                                                        curr_pos)
         return lin_dicts
 
 
@@ -928,11 +961,14 @@ class Species(OD):
         return result
 
 
-    # calculate stats for the lineages of a given set of nodes and loci;
-    # returns dict of struct: {k=stat, v={k=loc, v=[val_node1 ... val_node_N]}}
     def _calc_lineage_stats(self, individs=None, nodes=None, loci=None,
                             stats=['dir', 'dist', 'time', 'speed'],
+                            use_individs_curr_pos=True,
                             max_time_ago=None, min_time_ago=None):
+        '''
+        Calculate stats for the lineages of a given set of nodes and loci;
+        returns dict of struct: {k=stat, v={k=loc, v=[val_node1 ... val_node_N]}}
+        '''
         # get all nodes for the provided individuals, or for all individuals,
         # if nodes IDs not provided
         if nodes is None:
@@ -944,6 +980,7 @@ class Species(OD):
         if loci is None:
             loci = [*range(self.gen_arch.L)]
         lin_dicts = self._get_lineage_dicts(loci, nodes=nodes,
+                use_individs_curr_pos=use_individs_curr_pos,
                                             max_time_ago=max_time_ago,
                                             min_time_ago=min_time_ago)
         stats = {stat: {} for stat in stats}
@@ -1079,8 +1116,10 @@ class Species(OD):
         return ages
 
     # convenience method for getting whole species' phenotype
-    def _get_z(self, individs=None):
+    def _get_z(self, trait_num=None, individs=None):
         zs = self._get_scalar_attr('z', individs=individs)
+        if trait_num is not None:
+            zs = zs[:,trait_num]
         return zs
 
     #convenience method for getting whole species' fitnesses
@@ -1152,10 +1191,11 @@ class Species(OD):
             if ind not in keep:
                 self.pop(ind)
 
-    #use the kd_tree attribute to find nearest neighbors either
+    #use the kd_tree attribute to find mating pairs either
     #within the species, if within == True, or between the species
     #and the points provided, if within == False and points is not None
-    def _find_neighbors(self, dist, within=True, coords=None, k = 2):
+    def _get_mating_pairs(self, dist, within=True, coords=None,
+                          choose_nearest=False, inverse_dist_mating=False):
         #NOTE: In lieu of a more sophisticated way of
         #determining whether the kd_tree needs to be updated 
         #(i.e. if the species have undergone movement, mating,
@@ -1166,17 +1206,27 @@ class Species(OD):
         #model to rebuild it after each move, birth, or
         #death step could be unncessarily costly), for now I
         #am just telling the tree to be rebuilt each time 
-        #the spp.find_neighbors() method is called!
+        #the spp._get_mating_pairs() method is called!
         self._set_kd_tree()
         #if neighbors are to be found within the species,
         #set coords to self.coords (otherwise, the coords to
         #find nearest neighbors with should have been provided)
         if within:
             coords = self.coords
-        #query the tree
-        dists, pairs = self._kd_tree._query(coords = coords,
-                                                        dist = dist, k = k)
-        return(dists, pairs)
+
+        #query the tree to get mating pairs
+        pairs = self._kd_tree._get_mating_pairs(coords=coords,
+                                                dist=dist,
+                                                choose_nearest=choose_nearest,
+                                        inverse_dist_mating=inverse_dist_mating)
+
+        # use the species' birth rate to decide (as bernoulli draws)
+        # whether each pair can mate
+        can_mate = np.bool8(np.random.binomial(n=1, p=self.b,
+                                               size=pairs.shape[0]))
+        pairs = pairs[can_mate, :]
+        return pairs
+
 
     # method for plotting the species (or a subset of its individuals, by ID)
     # on top of a layer (or landscape)
@@ -1696,12 +1746,16 @@ class Species(OD):
         #show it
         plt.show()
 
-    def _plot_pop_growth(self):
+    def _plot_pop_growth(self, expected=True, actual=True, expected_color='red',
+                        actual_color='blue'):
         T = range(len(self.Nt))
         x0 = self.Nt[0] / self.K.sum()
-        plt.plot(T, [_calc_logistic_soln(x0, self.R,
-                                t) * self.K.sum() for t in T], color='red')
-        plt.plot(T, self.Nt, color='blue')
+        if expected:
+            plt.plot(T, [_calc_logistic_soln(x0, self.R,
+                                t) * self.K.sum() for t in T],
+                     color=expected_color)
+        if actual:
+            plt.plot(T, self.Nt, color=actual_color)
         plt.xlabel('t')
         plt.ylabel('N(t)')
 
@@ -1712,7 +1766,10 @@ class Species(OD):
         else:
             self._changer._plot_dem_changes(self)
 
+
     def _plot_example_recombinant_genome(self):
+        print('TODO: FIX ME!')
+        return
         assert self.gen_arch is not None, ("This species does not have "
                                             "genomes, so it cannot be used "
                                             "to plot an example recombinant "
@@ -1799,13 +1856,13 @@ def _make_species(land, name, idx, spp_params, burn=False, verbose=False):
 
     # print verbose output
     if verbose:
-        print('\t\tMAKING SPECIES %s...\n' % name)
+        print('\t\tMAKING SPECIES %s...\n' % name, flush=True)
 
     #if this species should have genomes, create the genomic architecture
     if 'gen_arch' in spp_params.keys():
         # print verbose output
         if verbose:
-            print('\t\t\tmaking genomic architecture...\n')
+            print('\t\t\tmaking genomic architecture...\n', flush=True)
         g_params = spp_params.gen_arch
         #make genomic_architecture
         gen_arch = _make_genomic_architecture(spp_params = spp_params,
@@ -1815,7 +1872,7 @@ def _make_species(land, name, idx, spp_params, burn=False, verbose=False):
 
     # print verbose output
     if verbose:
-        print('\t\t\tmaking individuals...\n')
+        print('\t\t\tmaking individuals...\n', flush=True)
     #make individs
     N = init_params.pop('N')
     #create an ordered dictionary to hold the individuals, and fill it up
@@ -1853,7 +1910,7 @@ def _make_species(land, name, idx, spp_params, burn=False, verbose=False):
         if 'move_surf' in spp_params.movement.keys():
             if verbose:
                 print(('\t\t\tmaking movement surface...\n'
-                       '\t\t\t\t[can take a bit]\n'))
+                       '\t\t\t\t[can take a bit]\n'), flush=True)
             ms_params = deepcopy(spp_params.movement.move_surf)
             #grab the lyr number for the lyr that the 
             #movement surface is to be based on
@@ -1874,7 +1931,7 @@ def _make_species(land, name, idx, spp_params, burn=False, verbose=False):
         # print verbose output
         if verbose:
             print(('\t\t\tmaking dispersal surface...\n'
-                   '\t\t\t\t[can take a bit]\n'))
+                   '\t\t\t\t[can take a bit]\n'), flush=True)
         ds_params = deepcopy(spp_params.movement.disp_surf)
         #grab the lyr number for the lyr that the 
         #dispersal surface is to be based on
@@ -1905,7 +1962,7 @@ def _make_species(land, name, idx, spp_params, burn=False, verbose=False):
         if verbose:
             print(('\t\t\tsetting up species changes...\n'
                    '\t\t\t\t[can take a while,\n\t\t\t\t if movement or '
-                   'dispersal\n\t\t\t\t surfaces will change]\n'))
+                   'dispersal\n\t\t\t\t surfaces will change]\n'), flush=True)
         #grab the change params (or None, if
         if 'change' in spp_params.keys():
             ch_params = spp_params.change
